@@ -12,19 +12,19 @@ use File::Basename ();
 use URI::Escape ();
 use Digest::MD5;
 
-our $VERSION = '0.990117';
+our $VERSION = '0.990118';
 
 use constant CHUNK_SIZE => 4096;
+use constant _DEFAULT_CACHE_DIR => '.text_haml_cache';
+my $cache_dir;
 
 BEGIN {
-    my $cache_dir = '.text_haml_cache';
     for my $dir ($ENV{HOME}, File::Spec->tmpdir) {
         if (defined($dir) && -d $dir && -w _) {
-            $cache_dir = File::Spec->catdir($dir, '.text_haml_cache');
+            $cache_dir = File::Spec->catdir($dir, _DEFAULT_CACHE_DIR);
             last;
         }
     }
-    use constant _DEFAULT_CACHE_DIR => $cache_dir;
 }
 
 my $ESCAPE = {
@@ -1385,11 +1385,11 @@ Text::Haml - Haml Perl implementation
 =head1 DESCRIPTION
 
 L<Text::Haml> implements Haml
-L<http://haml-lang.com/docs/yardoc/file.HAML_REFERENCE.html> specification.
+L<http://haml.info/docs/yardoc/file.REFERENCE.html> specification.
 
 L<Text::Haml> passes specification tests written by Norman Clarke
-http://github.com/norman/haml-spec and supports only cross-language Haml
-features. Do not expect Ruby specific things to work.
+https://github.com/haml/haml-spec and supports only cross-language Haml
+features. Do not expect ruby or Rails specific extensions to work.
 
 =head1 ATTRIBUTES
 
@@ -1665,9 +1665,11 @@ TheAthlete
 
 Mark Aufflick (aufflick)
 
+Graham Todd (grtodd)
+
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2009-2013, Viacheslav Tykhanovskyi.
+Copyright (C) 2009-2017, Viacheslav Tykhanovskyi.
 
 This program is free software, you can redistribute it and/or modify it under
 the terms of the Artistic License version 2.0.
